<?php
namespace brewpress\app\AdminSetting;

class Setting {

	public $settings_section = [ ];
	public $settings_field = [ ];
	public $field_type;
	private $settings_page = [ ];

	public function __construct(
		$settings_section = [ ],
		$settings_field = [ ],
		$field_type = 'text',
		$settings_page = [ ]
	) {
		$default_settings_section = [
			'id'       => '',
			'title'    => 'Custom Settings',
			'callback' => [ $this, 'callback_setting_section' ],
			'page'     => 'general',
			'args'     => ''
		];

		$default_settings_field = [
			'id'       => '',
			'label'    => 'Custom Setting',
			'callback' => [
				$this,
				'callback_setting_field_' . $field_type . ''
			],
			'page'     => 'general',
			'args'     => ''
		];

		$default_settings_page = [
			'page_title' => 'BrewPixel Widget Settings',
			'menu_title' => 'Brew Widget',
			'capability' => 'manage_options',
			'menu_slug'  => 'brew-widget-settings',
			'function'   => array( $this, 'view_admin_page' )
		];

		$this->field_type       = $field_type;
		$this->settings_section = $settings_section + $default_settings_section;
		$this->settings_field   = $settings_field + $default_settings_field;
		$this->settings_page    = $settings_page + $default_settings_page;

		if ( empty( $this->settings_field['id'] ) ) {
			$this->settings_field['id'] = sanitize_title_with_dashes( $this->settings_field['title'] );
		}

		if ( empty( $this->settings_section['id'] ) ) {
			$this->settings_section['id'] = sanitize_title_with_dashes( $this->settings_section['label'] );
		}

		add_action( 'admin_init',
			array( $this, 'site_initialise_theme_options' ) );

		$this->create_plugin_page( $settings_page );
	}


	/**
	 * Add options page
	 */
	public function add_plugin_page() {
		// This page will be under "Settings"
		add_options_page(
			$this->settings_page['page_title'],
			$this->settings_page['menu_title'],
			$this->settings_page['capability'],
			$this->settings_page['menu_slug'],
			$this->settings_page['function']
		);
	}

	/**
	 * Add options page
	 */
	public function create_plugin_page( $settings_page ) {
		if ( $settings_page ) {
			$this->settings_page = $settings_page + $this->settings_page;
			/* add this to add the settings page. we might need other code to go with this */
			add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
		}
	}

	/**
	 * Options page callback
	 */
	public function view_admin_page() {
		// Set class property
		//$this->settings_field = get_option( $this->settings_field['id'] );

		?>
		<div class="wrap">
			<h2><?php echo $this->settings_page['menu_title'] ?></h2>
			<form method="post" action="options.php">
				<?php
				// This prints out all hidden setting fields
				settings_fields( $this->settings_section['page'] );
				do_settings_sections( $this->settings_section['page'] );
				submit_button();
				?>
			</form>
		</div>
		<?php
	}

	public function site_initialise_theme_options() {
		/* ------------------------- *
		* Setting Registration
		* -------------------------- */

		/**
		 * Initialises the theme options page by registering the Sections,
		 * Fields, and Settings.
		 *
		 * This function is registered with the 'admin_init' hook.
		 */

		// First, we register a section. This is necessary since all future options must belong to one.

		// Social Section Settings
		add_settings_section(
			$this->settings_section['id'],
			// ID used to identify this section and with which to register options
			$this->settings_section['title'],
			// Title to be displayed on the administration page
			$this->settings_section['callback'],
			// Callback used to render the description of the section
			$this->settings_section['page'] // Page on which to add this section of options
		);

		// Next, we will introduce the fields for toggling the visibility of content elements.
		add_settings_field(
			$this->settings_field['id'],
			// ID used to identify the field throughout the theme
			$this->settings_field['label'],
			// The label to the left of the option interface element
			$this->settings_field['callback'],
			// The name of the function responsible for rendering the option interface
			$this->settings_section['page'],
			// The page on which this option will be displayed
			$this->settings_section['id'],
			// The name of the section to which this field belongs
			// The array of arguments to pass to the callback. In this case, just a description.
			$this->settings_field['args']
		);

		// Finally, we register the fields with WordPress
		register_setting(
			$this->settings_section['page'],
			$this->settings_field['id']
		);

	} // end site_initialize_theme_options

	public function callback_setting_section() {
		$callback_settings_section = $this->settings_section['args'];
		/* -------------------------------- *
		* Section Callbacks
		* --------------------------------- */

		/**
		 * This function provides a simple description for the General Options page.
		 *
		 * It is called from the 'site_initialize_theme_options' function by being passed as a parameter
		 * in the add_settings_section function.
		 */
		echo $callback_settings_section;
	}

	public function callback_setting_field_text() {

		/* --------------------------------------- *
		* Field Callbacks
		* ---------------------------------------- */

		/**
		 * This function renders the interface elements for toggling the visibility of the typekit_code element.
		 *
		 * It accepts an array of arguments and expects the first element in the array to be the description
		 * to be displayed next to the text.
		 */
		$helper_text = empty( $this->settings_field['args'] ) ? '' : $this->settings_field['args'][0];
		$html        = '<input type="text" id="' . $this->settings_field['id'] . '" name="' . $this->settings_field['id'] . '" value="' . get_option( $this->settings_field['id'] ) . '"/><p class="description">' . $helper_text . '</p>';

		echo $html;

	}

	public function callback_setting_field_textarea() {

		/* --------------------------------------- *
		* Field Callbacks
		* ---------------------------------------- */

		/**
		 * This function renders the interface elements for toggling the visibility of the typekit_code element.
		 *
		 * It accepts an array of arguments and expects the first element in the array to be the description
		 * to be displayed next to the text.
		 */
		$helper_text = empty( $this->settings_field['args'] ) ? '' : $this->settings_field['args'][0];
		$rows        = empty( $this->settings_field['args']['rows'] ) ? '10' : $this->settings_field['args']['rows'];
		$maxlength   = empty( $this->settings_field['args']['maxlength'] ) ? '' : 'maxlength="' . $this->settings_field['args']['maxlength'] . '"';
		$html = "<textarea name='" . $this->settings_field['id'] . "' ".$maxlength." rows='".$rows."' class='widefat'>" . get_option( $this->settings_field['id'] ) . "</textarea ><p class='description'> " . $helper_text . "</p >";

		echo $html;
	}

	public function callback_setting_field_wysiwyg() {

		/* --------------------------------------- *
		* Field Callbacks
		* ---------------------------------------- */

		/**
		 * This function renders the interface elements for toggling the visibility of the typekit_code element.
		 *
		 * It accepts an array of arguments and expects the first element in the array to be the description
		 * to be displayed next to the text.
		 */
		$helper_text = empty( $this->settings_field['args'] ) ? '' : $this->settings_field['args'][0];
		$quicktags_settings = array( 'buttons' => 'strong,em,link,block,del,ins,img,ul,ol,li,code,close' );
		//$field_value = get_post_meta( get_the_ID(), $this->settings_field['id'], false );
		$field_value = get_option( $this->settings_field['id'] );
		if(isset($field_value)){
			wp_editor( $field_value, $this->settings_field['id'], array( 'media_buttons' => false, 'tinymce' => true, 'quicktags' => $quicktags_settings ) );
		}
		else {
			wp_editor( '', $this->settings_field['id'], array( 'media_buttons' => false, 'tinymce' => true, 'quicktags' => $quicktags_settings ) );
		}


	}

	public function callback_setting_field_radio() {

		/* --------------------------------------- *
		* Field Callbacks
		* ---------------------------------------- */

		/**
		 * This function renders the interface elements for toggling the visibility of the typekit_code element.
		 *
		 * It accepts an array of arguments and expects the first element in the array to be the description
		 * to be displayed next to the text.
		 */
		$html = '<input type = "radio" name = "' . $this->settings_field['id'] . '" value = "on"' . checked( 'on' == get_option( $this->settings_field['id'] ) ) . ' /><input type = "radio" name = "' . $this->settings_field['id'] . '" value = "off"' . checked( 'off' == get_option( $this->settings_field['id'] ),
				false ) . ' /><p class="description" > ' . $this->settings_field['args'][0] . ' </p > ';

		echo $html;

	}

	public function callback_setting_field_checkbox() {

		/* --------------------------------------- *
		* Field Callbacks
		* ---------------------------------------- */

		/**
		 * This function renders the interface elements for toggling the visibility of the typekit_code element.
		 *
		 * It accepts an array of arguments and expects the first element in the array to be the description
		 * to be displayed next to the text.
		 */
		$html = '<input type = "checkbox" name = "' . $this->settings_field['id'] . '"' . checked( get_option( $this->settings_field['id'] ),
				true,
				false ) . ' value = "1" ><p class="description" > ' . $this->settings_field['args'][0] . ' </p > ';

		echo $html;

	}

	public function callback_setting_field_number() {
		$html = '<input type = "number" step = "1" min = "0" id = "' . $this->settings_field['id'] . '" name = "' . $this->settings_field['id'] . '" value = "' . get_option( $this->settings_field['id'] ) . '" class="small-text" > ';
		$html .= '<label for="' . $this->settings_field['id'] . '" >  '  . $this->settings_field['args'][0] . ' </label > ';
		echo $html;
	}

	/* New code to review */
	/*
	/**
		 * Sanitize each setting field as needed
		 *
		 * @param array $input Contains all settings fields as array keys
		 *//*
    public function sanitize( $input )
    {
        $new_input = array();
        if( isset( $input['id_number'] ) )
            $new_input['id_number'] = absint( $input['id_number'] );

        if( isset( $input['title'] ) )
            $new_input['title'] = sanitize_text_field( $input['title'] );

        return $new_input;
    }
*/
	/**
	 * Print the Section text
	 *//*
    public function print_section_info()
    {
        print 'Enter your settings below:';
    }
*/

}
